@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames
-Version : 1.0.1
+Version : 1.0.2
 Author  : Stefano Covino
-Date    : 01/10/2010
+Date    : 05/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -14,6 +14,7 @@ Remarks :
 
 History : (28/09/2010) First version.
         : (01/10/2010) Sextractor command names.
+        : (05/02/2012) Better path management.
 
 
 """
@@ -21,10 +22,12 @@ History : (28/09/2010) First version.
 import os.path
 
 import SRP
+from SRP.SRPSystem.SRPPath import SRPPath
+
 
 # SExtractor parameter sets for photometry
 
-BasePath        = os.path.join(SRP.__path__[0],'SRPData','SExtractor') 
+BasePath        = os.path.join(SRPPath(),'SRPData','SExtractor') 
 
 SexFName        = ("SRP.param", "SRP.conv", "SRP.nnw", "SRP.sex")
 
