@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Polarimetry
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 05/02/2012
+Date    : 09/04/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -16,11 +16,12 @@ Remarks : Valid only in 0.2:1.2 micron range
                 Opt. 34, 4755-4767 (1995)
 
 History : (05/02/2012) First version.
+        : (09/04/2013) More stable linear interpolation.
 
 """
 
 
-import atpy
+import atpy, numpy
 import os
 from scipy.interpolate import interp1d
 from SRP.SRPSystem.SRPPath import SRPPath
@@ -35,8 +36,8 @@ def AluminiumRefractiveIndex ():
     tw = t.where((t['lambda'] >= 0.2) & (t['lambda'] <= 1.2)) 
     tw.sort('lambda')
     #
-    n1 = interp1d(tw['lambda'], tw['n'], kind='quadratic', bounds_error=False)
-    k1 = interp1d(tw['lambda'], tw['k'], kind='quadratic', bounds_error=False)
+    n1 = interp1d(tw['lambda'], tw['n'], kind='linear', bounds_error=False)
+    k1 = interp1d(tw['lambda'], tw['k'], kind='linear', bounds_error=False)
     #
     return n1,k1
 
