@@ -2,20 +2,22 @@
 
 Context : SRP
 Module  : Polarimetry
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 21/02/2012
+Date    : 29/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
 Usage   : to be imported
 
 History : (21/02/2012) First named version.
+        : (29/02/2012) Wave plate matrix added.
 """
 
 
 __all__ = ['AluminiumRefractiveIndex', 'MuellerMetallicMirrorMatrix', 'MuellerRotationMatrix',
-            'MuellerTransmissionMatrix', 'Pol2Stokes', 'Stokes2Pol']
+            'MuellerTransmissionMatrix', 'MuellerHalfWavePlateMatrix', 'MuellerQuarterWavePlateMatrix',
+           'MuellerWavePlateMatrix', 'Pol2Stokes', 'Stokes2Pol']
 
 
 
